@@ -27,6 +27,7 @@ from zim.utils import get_module, lookup_subclass
 from zim.errors import Error
 from zim.notebook import Notebook, Path, \
 	get_notebook_list, resolve_notebook, build_notebook
+from zim.formats import get_format
 
 from .command import Command, GtkCommand, UsageError, GetoptError
 from .ipc import dispatch as _ipc_dispatch
@@ -141,14 +142,14 @@ class NotebookCommand(Command):
 
 		if notebook is None:
 			if self.arguments[0] == 'NOTEBOOK': # not optional
-				raise NotebookLookupError, _('Please specify a notebook')
+				raise NotebookLookupError(_('Please specify a notebook'))
 					# T: Error when looking up a notebook
 			else:
 				return None, None
 
 		notebookinfo = resolve_notebook(notebook, pwd=self.pwd)
 		if not notebookinfo:
-			raise NotebookLookupError, _('Could not find notebook: %s') % notebook
+			raise NotebookLookupError(_('Could not find notebook: %s') % notebook)
 				# T: error message
 
 		if len(self.arguments) > 1 \
@@ -175,7 +176,7 @@ class NotebookCommand(Command):
 		# mounting is attempted by zim.notebook.build_notebook()
 		notebookinfo, page = self.get_notebook_argument() 	# can raise NotebookLookupError
 		if not notebookinfo:
-			raise NotebookLookupError, _('Please specify a notebook')
+			raise NotebookLookupError(_('Please specify a notebook'))
 		notebook, uripage = build_notebook(notebookinfo) # can raise FileNotFound
 
 		if ensure_uptodate and not notebook.index.is_uptodate:
@@ -370,7 +371,7 @@ class ExportCommand(NotebookCommand):
 
 		format = self.opts.get('format', 'html')
 		if not 'output' in self.opts:
-			raise UsageError, _('Output location needed for export') # T: error in export command
+			raise UsageError(_('Output location needed for export')) # T: error in export command
 		output = Dir(self.opts['output'])
 		if not output.isdir():
 			output = File(self.opts.get('output'))
@@ -379,42 +380,46 @@ class ExportCommand(NotebookCommand):
 		if output.exists() and not self.opts.get('overwrite'):
 			if output.isdir():
 				if len(output.list()) > 0:
-					raise Error, _('Output folder exists and not empty, specify "--overwrite" to force export')  # T: error message for export
+					raise Error(_('Output folder exists and not empty, specify "--overwrite" to force export'))  # T: error message for export
 				else:
 					pass
 			else:
-				raise Error, _('Output file exists, specify "--overwrite" to force export')  # T: error message for export
+				raise Error(_('Output file exists, specify "--overwrite" to force export'))  # T: error message for export
 
 		if format == 'mhtml':
 			self.ignore_options('index-page')
 			if output.isdir():
-				raise UsageError, _('Need output file to export MHTML') # T: error message for export
+				raise UsageError(_('Need output file to export MHTML')) # T: error message for export
 
 			exporter = build_mhtml_file_exporter(
 				output, template,
 				document_root_url=self.opts.get('root-url'),
 			)
+		elif self.opts.get('singlefile'):
+			self.ignore_options('index-page')
+			if output.exists() and output.isdir():
+				ext = get_format(format).info['extension']
+				output = output.file(page.basename) + '.' + ext
+
+			exporter = build_single_file_exporter(
+				output, format, template, namespace=page,
+				document_root_url=self.opts.get('root-url'),
+			)
 		elif page:
 			self.ignore_options('index-page')
 			if output.exists() and output.isdir():
-				ext = 'html'
+				ext = get_format(format).info['extension']
 				output = output.file(page.basename) + '.' + ext
 
-			if self.opts.get('singlefile'):
-				exporter = build_single_file_exporter(
-					output, format, template, namespace=page,
-					document_root_url=self.opts.get('root-url'),
-				)
-			else:
-				exporter = build_page_exporter(
-					output, format, template, page,
-					document_root_url=self.opts.get('root-url'),
-				)
+			exporter = build_page_exporter(
+				output, format, template, page,
+				document_root_url=self.opts.get('root-url'),
+			)
 		else:
 			if not output.exists():
 				output = Dir(output.path)
 			elif not output.isdir():
-				raise UsageError, _('Need output folder to export full notebook') # T: error message for export
+				raise UsageError(_('Need output folder to export full notebook')) # T: error message for export
 
 			exporter = build_notebook_exporter(
 				output, format, template,
@@ -466,7 +471,7 @@ class SearchCommand(NotebookCommand):
 			logger.info('Searching for: %s', query)
 			query = Query(query)
 		else:
-			raise ValueError, 'Empty query'
+			raise ValueError('Empty query')
 
 		selection = SearchSelection(notebook)
 		selection.search(query)
@@ -488,7 +493,7 @@ class IndexCommand(NotebookCommand):
 
 
 commands = {
-	'help':  HelpCommand,
+	'help': HelpCommand,
 	'version': VersionCommand,
 	'gui': GuiCommand,
 	'manual': ManualCommand,
@@ -512,7 +517,7 @@ def build_command(args, pwd=None):
 		try:
 			cmd = args.pop(0)
 		except IndexError:
-			raise UsageError, 'Missing plugin name'
+			raise UsageError('Missing plugin name')
 
 		try:
 			mod = get_module('zim.plugins.' + cmd)
@@ -522,7 +527,7 @@ def build_command(args, pwd=None):
 				logger.exception('Error while loading: zim.plugins.%s.Command', cmd)
 				# Can't use following because log level not yet set:
 				# logger.debug('Error while loading: zim.plugins.%s.Command', cmd, exc_info=sys.exc_info())
-			raise UsageError, 'Could not load commandline command for plugin "%s"' % cmd
+			raise UsageError('Could not load commandline command for plugin "%s"' % cmd)
 	else:
 		if args and args[0].startswith('--') and args[0][2:] in commands:
 			cmd = args.pop(0)[2:]
@@ -660,7 +665,8 @@ class ZimApplication(object):
 	def _run_main_loop(self, cmd):
 		# Run for the 1st gtk command in a primary process,
 		# but can still be standalone process
-		import gtk, gobject
+		import gtk
+		import gobject
 
 		#######################################################################
 		# WARNING: commented out "gobject.threads_init()" because it leads to
@@ -772,7 +778,7 @@ class ZimApplication(object):
 	def _try_dispatch(self, args, pwd):
 		try:
 			_ipc_dispatch(pwd, *args)
-		except AssertionError, err:
+		except AssertionError as err:
 			logger.debug('Got error in dispatch: %s', str(err))
 			return False
 		except Exception:
