@@ -17,6 +17,7 @@ logger = logging.getLogger('zim.notebook.index')
 STATUS_UPTODATE = 0
 STATUS_CHECK = 1
 STATUS_NEED_UPDATE = 2
+STATUS_NEED_DELETION = 3
 
 TYPE_FOLDER = 1
 TYPE_FILE = 2
@@ -94,7 +95,7 @@ class FilesIndexer(SignalEmitter):
 				'SELECT id, path, node_type FROM files'
 				' WHERE index_status = ? AND path LIKE ?'
 				' ORDER BY node_type, id',
-				(STATUS_NEED_UPDATE, prefix+'%')
+				(STATUS_NEED_UPDATE, prefix + '%')
 			).fetchone()
 
 			if row:
@@ -192,7 +193,7 @@ class FilesIndexer(SignalEmitter):
 		logger.debug('Index folder: %s', folder)
 		self.db.execute(
 			'UPDATE files SET index_status = ? WHERE parent = ?',
-			(STATUS_NEED_UPDATE, node_id)
+			(STATUS_NEED_DELETION, node_id)
 		)
 
 		children = {}
@@ -210,7 +211,10 @@ class FilesIndexer(SignalEmitter):
 				if child.mtime() == child_mtime:
 					self.set_node_uptodate(child_id, child_mtime)
 				else:
-					pass # leave the STATUS_NEED_UPDATE for next loop
+					self.db.execute(
+						'UPDATE files SET index_status = ? WHERE id = ?',
+						(STATUS_NEED_UPDATE, child_id)
+					)
 			else:
 				# new child
 				node_type = TYPE_FILE if isinstance(child, File) else TYPE_FOLDER
@@ -231,6 +235,16 @@ class FilesIndexer(SignalEmitter):
 						(path, node_type, STATUS_NEED_UPDATE, node_id),
 					)
 
+		# Clean up nodes not found in listing
+		for child_id, child_type in self.db.execute(
+			'SELECT id, node_type FROM files WHERE parent=? AND index_status=?',
+			(node_id, STATUS_NEED_DELETION)
+		):
+			if child_type == TYPE_FOLDER:
+				self.delete_folder(child_id)
+			else:
+				self.delete_file(child_id)
+
 		self.set_node_uptodate(node_id, mtime)
 
 	def update_file(self, node_id, file):
@@ -278,7 +292,7 @@ class FilesIndexChecker(object):
 		if file is None:
 			file = self.folder
 		elif not (file == self.folder or file.ischild(self.folder)):
-			raise ValueError, 'file must be child of %s' % self.folder
+			raise ValueError('file must be child of %s' % self.folder)
 
 		# If path is not indexed, find parent that is
 		while not file == self.folder:
